@@ -3,7 +3,7 @@ package Locale::TextDomain::OO;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Carp qw(croak);
 use Cwd qw(abs_path);
@@ -468,13 +468,13 @@ __END__
 
 Locale::TextDomain::OO - Perl OO Interface to Uniforum Message Translation
 
-$Id: OO.pm 129 2009-11-30 09:21:28Z steffenw $
+$Id: OO.pm 150 2009-12-05 21:02:30Z steffenw $
 
 $HeadURL: https://perl-gettext-oo.svn.sourceforge.net/svnroot/perl-gettext-oo/trunk/lib/Locale/TextDomain/OO.pm $
 
 =head1 VERSION
 
-0.01
+0.02
 
 =head1 DESCRIPTION
 
@@ -487,7 +487,7 @@ This module is very similar to L<Locale::TextDomain>.
 The most important problem of Locale::TextDomain is the functional interface
 and consequently the use of the caller to figure out the text domain.
 That is why is not possible
-to wrap Locale:TextDomain functions into a new package.
+to wrap Locale::TextDomain functions into a new package.
 
 Locale::TextDomain::OO has a flexible object oriented interface.
 
@@ -539,12 +539,14 @@ because quant is an 'or'-construct.
 
 =item *
 
-The plural form is allowed after a number, followed by a whitespace,
+The plural form is allowed after a number,
+followed by a whitespace,
+not a non-breaking whitespace.
 
     1 book
     2 books
 
-but not before a number.
+A plural form can not be before a number.
 
     It is 1 book.
     These are 2 books.
@@ -562,6 +564,10 @@ Placeholders are numbered serially.
 It is difficult to translate this,
 because the sense of the phrase could be lost.
 
+    [_1] is a [_2] in [_3].
+
+    Erlangen is a town in Bavaria.
+
 =item *
 
 But there are a lot of modules around Locale::Maketext.
@@ -586,7 +592,8 @@ Named placeholders.
 Locale::TextDomain::OO can bind gettext subroutines
 or gettext methods.
 
-An example for binding subroutines is the default Locale::Messages.
+An example for binding subroutines is the default
+L<Locale::gettext_xs> or L<Locale::gettext_pp>.
 
 An example for object binding is L<Locale::TextDomain::OO::MessagesStruct>.
 
@@ -689,7 +696,7 @@ Run the examples of this distribution (folder example).
 
 =head2 method new
 
-=head3 optinal parameter text_domain
+=head3 optional parameter text_domain
 
 Set the default text domian __PACKAGE__.
 
@@ -839,7 +846,7 @@ or
 
 =head2 Translating methods
 
-How to bild the method name?
+How to build the method name?
 
 Use __ and append this with 'n', 'p' and/or 'x' in alphabetic order.
 
@@ -946,7 +953,7 @@ Use N__ and append this with 'n', 'p' and/or 'x' in alphabetic order.
 
 =head3 N__, N__x, N__n, N__nx, N__p, N__px, N__np, N__npx
 
-The extractor is looking for C<__('...'>
+The extractor looks for C<__('...'>
 and has no problem with C<$loc->N__('...')>.
 
 This is the idea of the N-Methods.
@@ -956,7 +963,8 @@ This is the idea of the N-Methods.
 =head1 EXAMPLE
 
 Inside of this Distribution is a directory named example.
-Run this *.pl files.
+Read the file README there.
+Then run the *.pl files.
 
 =head1 DIAGNOSTICS
 
@@ -1041,4 +1049,4 @@ This module is free software;
 you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
